==> ejc-trade-impl-3.0.0-20220627.094247-13-sources.jar: com/ejianc/business/trade/bean/SaleLibraryEntity.java <==
package com.ejianc.business.trade.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.trade.bean.SaleLibraryZiEntity;
/**
 * 销售库
 * 
 * @author generator
 * 
 */
 @TableName("t_trade_sale_library")
public class SaleLibraryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 销售单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="receive_id")
    private Long receiveId; // 收货单id
    @TableField(value="receive_date")
    private Date receiveDate; // 签收日期
    @TableField(value="accounts_due_date")
    private Date accountsDueDate; // 应收款日期
    @TableField(value="receive_num")
    private Integer receiveNum; // 收货总数
    @TableField(value="receive_price")
    private BigDecimal receivePrice; // 收货总金额
    @TableField(value="xxpbm")
    private String xxpbm; // 销项票编码
    @TableField(value="htzq")
    private Integer htzq; // 合同周期
    @TableField(value="yx")
    private BigDecimal yx; // 月息
    @TableField(value="purchase_price")
    private BigDecimal purchasePrice; // 采购总金额
    @TableField(value="cj")
    private BigDecimal cj; // 差价
    @TableField(value="qkzje")
    private BigDecimal qkzje; // 欠款总金额


    public BigDecimal getQkzje() {
        return qkzje;
    }

    public void setQkzje(BigDecimal qkzje) {
        this.qkzje = qkzje;
    }

    @TableField(exist=false)
    @SubEntity(serviceName="saleLibraryZiService", pidName = "zhuId")
    private List<SaleLibraryZiEntity> saleLibraryZiList = new ArrayList<>(); // 销售库子表
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getReceiveId() {
        return receiveId;
    }

    public void setReceiveId(Long receiveId) {
        this.receiveId = receiveId;
    }
    public Date getReceiveDate() {
        return receiveDate;
    }

    public void setReceiveDate(Date receiveDate) {
        this.receiveDate = receiveDate;
    }
    public Date getAccountsDueDate() {
        return accountsDueDate;
    }

    public void setAccountsDueDate(Date accountsDueDate) {
        this.accountsDueDate = accountsDueDate;
    }
    public Integer getReceiveNum() {
        return receiveNum;
    }

    public void setReceiveNum(Integer receiveNum) {
        this.receiveNum = receiveNum;
    }
    public BigDecimal getReceivePrice() {
        return receivePrice;
    }

    public void setReceivePrice(BigDecimal receivePrice) {
        this.receivePrice = receivePrice;
    }
    public String getXxpbm() {
        return xxpbm;
    }

    public void setXxpbm(String xxpbm) {
        this.xxpbm = xxpbm;
    }
    public Integer getHtzq() {
        return htzq;
    }

    public void setHtzq(Integer htzq) {
        this.htzq = htzq;
    }
    public BigDecimal getYx() {
        return yx;
    }

    public void setYx(BigDecimal yx) {
        this.yx = yx;
    }
    public BigDecimal getPurchasePrice() {
        return purchasePrice;
    }

    public void setPurchasePrice(BigDecimal purchasePrice) {
        this.purchasePrice = purchasePrice;
    }
    public BigDecimal getCj() {
        return cj;
    }

    public void setCj(BigDecimal cj) {
        this.cj = cj;
    }
    

    public List<SaleLibraryZiEntity> getSaleLibraryZiList() {
        return saleLibraryZiList;
    }

    public void setSaleLibraryZiList(List<SaleLibraryZiEntity> saleLibraryZiList) {
        this.saleLibraryZiList = saleLibraryZiList;
    }
}

==> ejc-trade-impl-3.0.0-20251208.064703-45-sources.jar: com/ejianc/business/trade/bean/SaleLibraryEntity.java <==
package com.ejianc.business.trade.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.trade.bean.SaleLibraryZiEntity;
/**
 * 销售库
 * 
 * @author generator
 * 
 */
 @TableName("t_trade_sale_library")
public class SaleLibraryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 销售单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="receive_id")
    private Long receiveId; // 收货单id
    @TableField(value="receive_date")
    private Date receiveDate; // 签收日期
    @TableField(value="accounts_due_date")
    private Date accountsDueDate; // 应收款日期
    @TableField(value="receive_num")
    private Integer receiveNum; // 收货总数
    @TableField(value="receive_price")
    private BigDecimal receivePrice; // 收货总金额
    @TableField(value="xxpbm")
    private String xxpbm; // 销项票编码
    @TableField(value="htzq")
    private Integer htzq; // 合同周期
    @TableField(value="yx")
    private BigDecimal yx; // 月息
    @TableField(value="purchase_price")
    private BigDecimal purchasePrice; // 采购总金额
    @TableField(value="cj")
    private BigDecimal cj; // 差价
    @TableField(value="qkzje")
    private BigDecimal qkzje; // 欠款总金额
    @TableField(value="sfkjxp")
    private String sfkjxp; // 是否开进项票
    @TableField(value="dhdw_id")
    private Long dhdwId; // 订货单位id
    @TableField(value="dhdw_name")
    private String dhdwName; // 订货单位名称


    public Long getDhdwId() {
        return dhdwId;
    }

    public void setDhdwId(Long dhdwId) {
        this.dhdwId = dhdwId;
    }

    public String getDhdwName() {
        return dhdwName;
    }

    public void setDhdwName(String dhdwName) {
        this.dhdwName = dhdwName;
    }

    public String getSfkjxp() {
        return sfkjxp;
    }

    public void setSfkjxp(String sfkjxp) {
        this.sfkjxp = sfkjxp;
    }

    public BigDecimal getQkzje() {
        return qkzje;
    }

    public void setQkzje(BigDecimal qkzje) {
        this.qkzje = qkzje;
    }

    @TableField(exist=false)
    @SubEntity(serviceName="saleLibraryZiService", pidName = "zhuId")
    private List<SaleLibraryZiEntity> saleLibraryZiList = new ArrayList<>(); // 销售库子表
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getReceiveId() {
        return receiveId;
    }

    public void setReceiveId(Long receiveId) {
        this.receiveId = receiveId;
    }
    public Date getReceiveDate() {
        return receiveDate;
    }

    public void setReceiveDate(Date receiveDate) {
        this.receiveDate = receiveDate;
    }
    public Date getAccountsDueDate() {
        return accountsDueDate;
    }

    public void setAccountsDueDate(Date accountsDueDate) {
        this.accountsDueDate = accountsDueDate;
    }
    public Integer getReceiveNum() {
        return receiveNum;
    }

    public void setReceiveNum(Integer receiveNum) {
        this.receiveNum = receiveNum;
    }
    public BigDecimal getReceivePrice() {
        return receivePrice;
    }

    public void setReceivePrice(BigDecimal receivePrice) {
        this.receivePrice = receivePrice;
    }
    public String getXxpbm() {
        return xxpbm;
    }

    public void setXxpbm(String xxpbm) {
        this.xxpbm = xxpbm;
    }
    public Integer getHtzq() {
        return htzq;
    }

    public void setHtzq(Integer htzq) {
        this.htzq = htzq;
    }
    public BigDecimal getYx() {
        return yx;
    }

    public void setYx(BigDecimal yx) {
        this.yx = yx;
    }
    public BigDecimal getPurchasePrice() {
        return purchasePrice;
    }

    public void setPurchasePrice(BigDecimal purchasePrice) {
        this.purchasePrice = purchasePrice;
    }
    public BigDecimal getCj() {
        return cj;
    }

    public void setCj(BigDecimal cj) {
        this.cj = cj;
    }
    

    public List<SaleLibraryZiEntity> getSaleLibraryZiList() {
        return saleLibraryZiList;
    }

    public void setSaleLibraryZiList(List<SaleLibraryZiEntity> saleLibraryZiList) {
        this.saleLibraryZiList = saleLibraryZiList;
    }
}
